.. _aggregator:

Aggregator
==========

After fitting a large suite of strong lens data, the **aggregator** allows you to load the results and manipulate,
interpret and visualize them using a Python script or Jupyter notebook.

The readthedocs overview for the **aggregator** is not written yet, so checkout
`the aggregator tutorials on the autolens workspace <https://github.com/Jammy2211/autolens_workspace/tree/master/advanced/aggregator>`_
for a full description of the feature.